/* multimon - CGI program to monitor several UPSes from one page

   Copyright (C) 1998  Russell Kroll <rkroll@exploits.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              
 */

#include <unistd.h>
#include <stdio.h>
#include <syslog.h>
#include <stdlib.h>
#include <string.h>
#include <sys/time.h>

#include "multimon.h"
#include "upsfetch.h"
#include "config.h"
#include "version.h"

typedef struct {
	char	*var;
	char	*name;
	char	*suffix;
	void	*next;
}	ftype;

	ftype	*firstfield = NULL;
	int	numfields = 0;
	char	*desc;

void report_error(char *str) 
{
    printf("%s</BODY></HTML>\n", str);
    exit(1);
}

void noresp()
{
	printf ("<TD BGCOLOR=\"#FF0000\">Unavailable</TD>\n");
}

/* handler for "STATUS" */
void do_status(char *monhost)
{
	char	status[64], *stat, color[16], stattxt[128];

 	if (getupsvar (monhost, "status", status, sizeof(status)) < 0) {
		noresp();
		return;
	}

	strcpy (stattxt, "");
	strcpy (color, "#FFFF00");	/* default: yellow */

	/* colors are set to red for bad situations and green for good ones */

	/* they are left alone for "in between" ones, and the default
	   (yellow) may be used in that case */

	stat = strtok (status, " ");
	while (stat != NULL) {	
		if (!strcasecmp(stat, "OFF")) {
			strcat (stattxt, "OFF<BR>");
			strcpy (color, "#FFFF00");
		}

		if (!strcasecmp(stat, "OL")) {
			strcat (stattxt, "ONLINE<BR>");
			strcpy (color, "#00FF00");
		}

		if (!strcasecmp(stat, "OB")) {
			strcat (stattxt, "ON BATTERY<BR>");
			strcpy (color, "#FF0000");
		} 

		if (!strcasecmp(stat, "LB")) {
			strcat (stattxt, "BATTERY LOW<BR>");
			strcpy (color, "#FF0000");
		}

		if (!strcasecmp(stat, "CAL")) {
			strcat (stattxt, "CALIBRATION<BR>");
		}
		stat = strtok (NULL, " ");
	} 

	printf ("<TD BGCOLOR=\"%s\">%s</TD>\n", color, stattxt);
}

/* handler for "MODEL" */
void do_model (char *monhost)
{
	char	model[256];

	if (getupsvar (monhost, "model", model, sizeof(model)) < 0) {
		noresp();
		return;
	}

	printf ("<TD BGCOLOR=\"#00FFFF\">%s</TD>\n", model);
	return;
}

/* handler for "UPSTEMP" */
void do_upstemp (char *monhost)
{
	char	upstemp[64];
	float	tempf;

	if (getupsvar (monhost, "upstemp", upstemp, sizeof(upstemp)) > 0) {
		tempf = (strtod (upstemp, 0) * 1.8) + 32;
#ifdef USE_CELSIUS
		printf ("<TD BGCOLOR=\"#00FF00\">%s C</TD>\n", upstemp); 
#else
		printf ("<TD BGCOLOR=\"#00FF00\">%.1f F</TD>\n", tempf); 
#endif
	}
	else
		printf ("<TD></TD>\n");
}

/* handler for "AMBTEMP" */
void do_ambtemp (char *monhost)
{
	char	ambtemp[64];
	float	tempf;

	if (getupsvar (monhost, "ambtemp", ambtemp, sizeof(ambtemp)) > 0) {
		tempf = (strtod (ambtemp, 0) * 1.8) + 32;
#ifdef USE_CELSIUS
		printf ("<TD BGCOLOR=\"#00FF00\">%s C</TD>\n", ambtemp); 
#else
		printf ("<TD BGCOLOR=\"#00FF00\">%.1f F</TD>\n", tempf); 
#endif
	}
	else
		printf ("<TD></TD>\n");
}

void getinfo (char *monhost)
{
	ftype	*tmp;
	char	tmpbuf[256];
	int	i, found;

	printf ("<TR ALIGN=CENTER>\n");

	/* provide system name and link to upsstats */
	printf ("<TD BGCOLOR=\"#00FFFF\">");
	printf ("<A HREF=\"upsstats.cgi?host=%s\">%s</A></TD>\n", monhost, 
	        desc);

	/* grab a dummy variable to see if the host is up */
	if (getupsvar(monhost, "model", tmpbuf, sizeof(tmpbuf)) < 0) {
		printf ("<TD COLSPAN=%i BGCOLOR=\"#FF0000\">Error: %s</TD></TR>\n",
		        numfields, upsstrerror(upserror));
		return;
	}

	/* process each field one by one */
	for (tmp = firstfield; tmp != NULL; tmp = tmp->next) {
		found = 0;

		/* search for a recognized special field name */
		for (i = 0; fields[i].name != NULL; i++) {
			if (!strcmp(fields[i].name, tmp->var)) {
				fields[i].func(monhost);
				found = 1;
			}
		}

		if (found)
			continue;

		if (getupsvar(monhost, tmp->var, tmpbuf, sizeof(tmpbuf)) > 0) {
			if (tmp->suffix == NULL)
				printf ("<TD BGCOLOR=\"#00FF00\">%s</TD>\n", 
				        tmpbuf);
			else
				printf ("<TD BGCOLOR=\"#00FF00\">%s %s</TD>\n", 
				        tmpbuf, tmp->suffix);
		}
		else
			printf ("<TD></TD>\n");
	}

	printf ("</TR>\n");

	return;
}

/* add a field to the linked list */
void addfield (char *var, char *name, char *suffix)
{
	ftype	*tmp, *last;

	tmp = last = firstfield;

	while (tmp != NULL) {
		last = tmp;
		tmp = tmp->next;
	}

	tmp = malloc (sizeof (ftype));
	tmp->var = var;
	tmp->name = name;
	tmp->suffix = suffix;
	tmp->next = NULL;

	if (last == NULL)
		firstfield = tmp;
	else
		last->next = tmp;

	numfields++;
}

/* parse a FIELD line from the buf and call addfield */
void parsefield (char *buf)
{
	char *ptr, *var, *name = NULL, *suffix = NULL, *tmp;
	int i = 0, in_string = 0;

	tmp = malloc(strlen(buf) + 1);

	/* <variable> "<field name>" "<field suffix>" */

	ptr = strtok(buf, " ");
	if (ptr == NULL) {
		report_error("multimon.conf: "
			     "No separating space in FIELD line.");
	}
	var = strdup(ptr);

	ptr = buf + strlen(var) + 1;
	while (*ptr) {
		if (*ptr == '"') {
			in_string = !in_string;
			if (!in_string) {
				tmp[i] = '\0';
				i = 0;
				if (suffix) {
					sprintf(tmp, "multimon.conf: "
						"More than two strings "
						"in field %s.", var);
					report_error(tmp);
				}
				else if (name) {
					suffix = strdup(tmp);
				}
				else {
					name = strdup(tmp);
				}
			}
		}
		else if (in_string) {
			if (*ptr == '\\') {
				++ptr;
				if (*ptr == '\0') {
					sprintf(tmp, "multimon.conf: "
						"Backslash at end of line "
						"in field %s.", var);
					report_error(tmp);
				}
			}
			tmp[i++] = *ptr;
		}
		++ptr;
	}

	if (in_string) {
		sprintf(tmp, "multimon.conf: "
			"Unbalanced quotes in field %s!", var);
		report_error(tmp);
	}

	free(tmp);

	addfield (var, name, suffix);
}	

void readconf()
{
	FILE	*conf;
	char	buf[512], fn[256];

	snprintf (fn, sizeof(fn), "%s/multimon.conf", CONFPATH);
	conf = fopen (fn, "r");

	/* the config file is not required */
	if (conf == NULL)
		return;

	while (fgets (buf, sizeof(buf), conf)) {
		buf[strlen(buf) - 1] = 0;
		if (!strncmp (buf, "FIELD", 5))
			parsefield (&buf[6]);
	}

	fclose (conf);
}	

/* create default field configuration */
void defaultfields()
{
	addfield ("MODEL", "Model", "");
	addfield ("STATUS", "Status", "");
	addfield ("battpct", "Batt Chg", "%");
	addfield ("utility", "Utility", "VAC");
	addfield ("loadpct", "UPS Load", "%");
	addfield ("UPSTEMP", "UPS Temperature", "");
}	

int main() 
{
	FILE	*conf;
	time_t	tod;
	char	buf[256], fn[256], addr[256], timestr[256], *rest;
	int	restofs;
	ftype	*tmp;

        /* print out header first so we can give error reports */
	printf ("Content-type: text/html\n");
	printf ("\n");

	printf ("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\"\n");
	printf ("	\"http://www.w3.org/TR/REC-html40/loose.dtd\">\n");

	printf ("<HTML>\n");
	printf ("<HEAD><TITLE>Multimon: UPS Status Page</TITLE></HEAD>\n");
	printf ("<BODY BGCOLOR=\"#FFFFFF\">\n");

	readconf();

	if (firstfield == NULL)		/* nothing from config file? */
		defaultfields();

	printf ("<TABLE BGCOLOR=\"#50A0A0\" ALIGN=CENTER>\n");
	printf ("<TR><TD>\n");
	printf ("<TABLE CELLPADDING=5>\n");
	printf ("<TR>\n");
	
	time (&tod);
	strftime (timestr, 100, "%a %b %d %X %Z %Y", localtime(&tod));

	printf ("<TH COLSPAN=%i BGCOLOR=\"#60B0B0\">\n", numfields + 1);
	printf ("<FONT SIZE=\"+2\">Smart UPS Tools multimon %s</FONT>\n", 
	        UPS_VERSION);
	printf ("<BR>%s</TH>\n", timestr);
	printf ("</TR>\n"); 

	printf ("<TR BGCOLOR=\"#60B0B0\">\n");

	/* first column is always 'system' */

	printf ("<TH COLSPAN=1>System</TH>\n");

	/* print column names */
	for (tmp = firstfield; tmp != NULL; tmp = tmp->next)
		printf ("<TH COLSPAN=1>%s</TH>\n", tmp->name);

	printf ("</TR>\n"); 

	/* ups status */

	snprintf (fn, sizeof(fn), "%s/hosts.conf", CONFPATH);
	conf = fopen (fn, "r");

	while (fgets (buf, sizeof(buf), conf)) 
		if (strncmp("MONITOR", buf, 4) == 0) {
			sscanf (buf, "%*s %s %n", addr, &restofs);
			rest = buf + restofs + 1;
			desc = strtok (rest, "\"");
			getinfo (addr);
		}

	fclose (conf);
	
	printf ("</TABLE>\n"); 
	printf ("</TD></TR>\n"); 
	printf ("</TABLE></BODY></HTML>\n");

	return (1);
}
